DIECFG2

Type Alias DIECFG2 

pub type DIECFG2 = Reg<u32, _DIECFG2>;
These settings are a function of the FLASH information page bit settings, which are programmed during production test, and are subject for specific configuration for multiple device flavors of cc2538. The DIE_*_REVISION registers are an exeception to this, as they are hardwired and are not part of the FLASH information page.

This register you can read, reset, write, write_with_zero, modify. See API.

For information about avaliable fields see diecfg2 module

Aliased Type

pub struct DIECFG2 { /* private fields */ }