pub type R = R<u32, CTRL>;Expand description
Reader of register CTRL
Aliased Type
pub struct R { /* private fields */ }Implementations
Sourceimpl R
impl R
Sourcepub fn reserved28(&self) -> RESERVED28_R
pub fn reserved28(&self) -> RESERVED28_R
Bits 4:31 - 31:4] Software should not rely on the value of a reserved bit. To provide compatibility with future products, the value of a reserved bit should be preserved across a read-modify-write operation.
Sourcepub fn ack(&self) -> ACK_R
pub fn ack(&self) -> ACK_R
Bit 3 - 3:3] Data acknowledge enable 0: The received data byte is not acknowledged automatically by the master. 1: The received data byte is acknowledged automatically by the master.
Sourcepub fn stop(&self) -> STOP_R
pub fn stop(&self) -> STOP_R
Bit 2 - 2:2] Generate STOP 0: The controller does not generate the STOP condition. 1: The controller generates the STOP condition.