W

Type Alias W 

pub type W = W<u32, SRCRC>;
Writer for register SRCRC

Aliased Type

pub struct W { /* private fields */ }

Implementations

Source

impl W

pub fn reserved32(&mut self) -> RESERVED32_W<'_>

Bits 13:31 - 31:13] This register is 8 bits in a 32-bit address space.

pub fn reserved12(&mut self) -> RESERVED12_W<'_>

Bit 12 - 12:12] Reserved

pub fn reserved10(&mut self) -> RESERVED10_W<'_>

Bits 10:11 - 11:10] Software should not rely on the value of a reserved bit. To provide compatibility with future products, the value of a reserved bit should be preserved across a read-modify-write operation.

pub fn reserved9(&mut self) -> RESERVED9_W<'_>

Bit 9 - 9:9] Reserved

pub fn crc_ren_usb(&mut self) -> CRC_REN_USB_W<'_>

Bit 8 - 8:8] 1: Enable reset of chip if CRC fails. 0: Disable reset feature of chip due to CRC.

pub fn reserved8(&mut self) -> RESERVED8_W<'_>

Bits 5:7 - 7:5] Reserved

pub fn reserved4(&mut self) -> RESERVED4_W<'_>

Bit 4 - 4:4] Reserved

pub fn reserved2(&mut self) -> RESERVED2_W<'_>

Bits 2:3 - 3:2] Software should not rely on the value of a reserved bit. To provide compatibility with future products, the value of a reserved bit should be preserved across a read-modify-write operation.

pub fn reserved1(&mut self) -> RESERVED1_W<'_>

Bit 1 - 1:1] Reserved

pub fn crc_ren_rf(&mut self) -> CRC_REN_RF_W<'_>

Bit 0 - 0:0] 1: Enable reset of chip if CRC fails. 0: Disable reset feature of chip due to CRC.