R

Type Alias R 

pub type R = R<u32, PP>;
Reader of register PP

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn reserved30(&self) -> RESERVED30_R

Bits 2:31 - 31:2] Software should not rely on the value of a reserved bit. To provide compatibility with future products, the value of a reserved bit should be preserved across a read-modify-write operation.

pub fn nb(&self) -> NB_R

Bit 1 - 1:1] 9-bit support 1: The UART module provides support for the transmission of 9-bit data for RS-485 support. 0: The UART module does not provide support for the transmission of 9-bit data for RS-485 support.

pub fn sc(&self) -> SC_R

Bit 0 - 0:0] Smart card support 1: The UART module provides smart card support. 0: The UART module does not provide smart card support.