FR

Type Alias FR 

pub type FR = Reg<u32, _FR>;
UART flag The FR register is the flag register. After reset, the TXFF, RXFF, and BUSY bits are 0, and TXFE and RXFE bits are 1. The CTS bit indicate the modem flow control. Note that the modem bits are only implemented on UART1 and are tied inactive on UART0. Due to this difference, the reset state of the UART0 FR register is 0x90, while UART1 FR register reset state 0x197 .

This register you can read, reset, write, write_with_zero, modify. See API.

For information about avaliable fields see fr module

Aliased Type

pub struct FR { /* private fields */ }