pub struct RegisterBlock {
pub fctl: FCTL,
pub faddr: FADDR,
pub fwdata: FWDATA,
pub diecfg0: DIECFG0,
pub diecfg1: DIECFG1,
pub diecfg2: DIECFG2,
/* private fields */
}Expand description
Register block
Fields
fctl: FCTL0x08 - Flash control This register provides control and monitoring functions for the flash module.
faddr: FADDR0x0c - Flash address The register sets the address to be written in flash memory. See the bitfield descriptions for formatting information.
fwdata: FWDATA0x10 - Flash data This register contains the 32-bits of data to be written to the flash location selected in FADDR.
diecfg0: DIECFG00x14 - These settings are a function of the FLASH information page bit settings, which are programmed during production test, and are subject for specific configuration for multiple device flavors of cc2538.
diecfg1: DIECFG10x18 - These settings are a function of the FLASH information page bit settings, which are programmed during production test, and are subject for specific configuration for multiple device flavors of cc2538.
diecfg2: DIECFG20x1c - These settings are a function of the FLASH information page bit settings, which are programmed during production test, and are subject for specific configuration for multiple device flavors of cc2538. The DIE_*_REVISION registers are an exeception to this, as they are hardwired and are not part of the FLASH information page.