pub type R = R<u32, PP>;Expand description
Reader of register PP
Aliased Type
pub struct R { /* private fields */ }Implementations
Sourceimpl R
impl R
Sourcepub fn reserved30(&self) -> RESERVED30_R
pub fn reserved30(&self) -> RESERVED30_R
Bits 2:31 - 31:2] Software should not rely on the value of a reserved bit. To provide compatibility with future products, the value of a reserved bit should be preserved across a read-modify-write operation.