pub type RIS = Reg<u32, _RIS>;Expand description
UART raw interrupt status The RIS register is the raw interrupt status register. On a read, this register gives the current raw status value of the corresponding interrupt. A write has no effect. Note that the HW modem flow control bits are only implemented on UART1 and are tied inactive on UART0.
This register you can read, reset, write, write_with_zero, modify. See API.
For information about avaliable fields see ris module
Aliased Type
pub struct RIS { /* private fields */ }